![](https://raw.githubusercontent.com/xiaoxiae/Florodoro/master/florodoro/images/logo.svg)

---

A pomodoro timer that grows procedurally generated trees and flowers while you're studying.

![](https://raw.githubusercontent.com/xiaoxiae/Florodoro/master/florodoro/images/preview.svg)

## Running Florodoro
First, install the app by running `pip install florodoro`.
Then you can simply run the `florodoro` command from a terminal of your choice.

If you'd like to always have the latest (unstable) version, install from TestPyPI using `pip install -i https://test.pypi.org/simple/ florodoro`

## Controls

### Top bar
- **Presets** – contains common pomodoro timings for study/break/cycle
- **Options**
	- **Notify** – notification options (sound/pop-ups)
	- **Plants** – plant settings (which ones to grow)
	- **Overstudy** – enables doing a break earlier/later than specified, allowing for more "organic" study sessions
- **Statistics** – shows statistics regarding time studied; includes an interactive gallery of previously grown plants
- **About** – a small TLDR about the project

### Bottom bar
- **Study for: <>** – how long to study for
- **Break for: <>** – how long to break after study
- **Icon: Cycles: <>** – how many times to repeat study-break
- **Icon: Book** – start the study session
- **Icon: Coffee** – start a break
- **Icon: Pause/continue** – pause/continue an ongoing study/break
- **Icon: Reset** – reset everything
